@@ -52,6 +52,12 @@
 # endif
 #endif
 
+#ifdef OFFLINE
+#ifdef HAVE_RAPTOR
+#include <raptor.h>
+#endif
+#endif
+
 #include <flickcurl.h>
 #include <flickcurl_internal.h>
 
@@ -279,6 +285,7 @@ flickcurl_init(void)
 {
   curl_global_init(CURL_GLOBAL_ALL);
   xmlInitParser();
+  flickcurl_serializer_init();
   return 0;
 }
 
@@ -291,6 +298,7 @@ flickcurl_init(void)
 void
 flickcurl_finish(void)
 {
+  flickcurl_serializer_terminate();
   xmlCleanupParser();
   curl_global_cleanup();
 }
@@ -921,12 +929,22 @@ flickcurl_invoke(flickcurl *fc)
 
 #ifdef OFFLINE
   if(1) {
+#ifdef HAVE_RAPTOR
+    char* uri_string;
+#endif
+    
     if(access(filename, R_OK)) {
       fprintf(stderr, "Method %s cannot run offline - no %s XML result available\n",
               fc->method, filename);
       return NULL;
     }
+#ifdef HAVE_RAPTOR
+    uri_string=raptor_uri_filename_to_uri_string(filename);
+    strcpy(fc->uri, uri_string);
+    raptor_free_memory(uri_string);
+#else
     sprintf(fc->uri, "file:%s", filename);
+#endif
     fprintf(stderr, "Method %s: running offline using result from %s\n", 
             fc->method, filename);
   }
@@ -1214,6 +1232,29 @@ flickcurl_unixtime_to_sqltimestamp(time_t unix_time)
 }
 
 
+char*
+flickcurl_sqltimestamp_to_isotime(const char* timestamp)
+{
+/* SQL DATETIME FORMAT "%Y %m %d %H:%M:%S"  (19 chars) */
+/* ISO DATE FORMAT     "%Y-%m-%dT%H:%M:%SZ" (20 chars) */
+#define ISO_DATE_LEN 20
+  size_t len=ISO_DATE_LEN;
+  char *value=NULL;
+  
+  value=(char*)malloc(len + 1);
+  strncpy((char*)value, timestamp, len);
+  value[4]='-';
+  value[7]='-';
+  value[10]='T';
+  value[13]=':';
+  value[16]=':';
+  value[19]='Z';
+  value[20]='\0';
+  
+  return value;
+}
+
+
 char*
 flickcurl_xpath_eval(flickcurl *fc, xmlXPathContextPtr xpathCtx,
                      const xmlChar* xpathExpr) 
@@ -1359,11 +1400,10 @@ flickcurl_call_get_one_string_field(flickcurl* fc,
   xmlDocPtr doc=NULL;
   xmlXPathContextPtr xpathCtx=NULL; 
 
-  if(!value)
-    return NULL;
-  
-  parameters[count][0]  = key;
-  parameters[count++][1]= value;
+  if(key && value) {
+    parameters[count][0]  = key;
+    parameters[count++][1]= value;
+  }
 
   parameters[count][0]  = NULL;
 
@@ -1447,7 +1487,7 @@ flickcurl_array_split(const char *str, char delim)
       array_size++;
   }
   
-  array=(char**)malloc(array_size+1);
+  array=(char**)malloc(sizeof(char*)*(array_size+1));
   if(!array)
     return NULL;
 
@@ -1493,3 +1533,114 @@ flickcurl_array_free(char* array[])
   free(array);
 }
 
+
+#define CONTENT_TYPE_COUNT 3
+static const char* flickcurl_content_type_labels[CONTENT_TYPE_COUNT+1]=
+  {"unknown", "photo", "screenshot", "other"};
+
+
+/**
+ * flickcurl_get_content_type_label:
+ * @content_type: safety level index
+ * 
+ * Get label for a content type.
+ *
+ * Return value: pointer to shared string label for content type or "unknown"
+ **/
+const char*
+flickcurl_get_content_type_label(int content_type)
+{
+  if(content_type < 1 || content_type > CONTENT_TYPE_COUNT)
+    content_type= 0;
+  return flickcurl_content_type_labels[content_type];
+}
+
+
+/**
+ * flickcurl_get_content_type_from_string:
+ * @content_type_string: string
+ * 
+ * Get the enumeration value for a content type string.
+ *
+ * Parses the string value into a content type either from an
+ * integer form like '1' or a label like 'photo'.
+ * 
+ * Returns: content type enumeration value or <0 on error
+ **/
+int
+flickcurl_get_content_type_from_string(const char* content_type_string)
+{
+  char* endptr=NULL;
+  int content_type = -1;
+
+  content_type=(int)strtol(content_type_string, &endptr, 10);
+  /* If not all of string was used - fail */
+  if(endptr && *endptr)
+    content_type= -1;
+  if(content_type < 1 || content_type > CONTENT_TYPE_COUNT) {
+    int i;
+    for(i=1; i< CONTENT_TYPE_COUNT; i++)
+      if(!strcmp(flickcurl_content_type_labels[i], content_type_string)) {
+        content_type=i;
+        break;
+      }
+  }
+
+  return content_type;
+}
+
+
+#define SAFETY_LEVEL_COUNT 4
+static const char* flickcurl_safety_level_labels[SAFETY_LEVEL_COUNT+1]=
+  {"unknown", "safe", "moderate", "restricted", "(no change)"};
+
+
+/**
+ * flickcurl_get_safety_level_label:
+ * @safety_level: safety level index
+ * 
+ * Get label for a safety level.
+ *
+ * Return value: pointer to shared string label for safety level or "unknown"
+ **/
+const char*
+flickcurl_get_safety_level_label(int safety_level)
+{
+  if(safety_level < 1 || safety_level > SAFETY_LEVEL_COUNT)
+    safety_level= 0;
+  return flickcurl_safety_level_labels[safety_level];
+}
+
+
+/**
+ * flickcurl_get_safety_level_from_string:
+ * @safety_level_string: string
+ * 
+ * Get the enumeration value for a safety level string.
+ *
+ * Parses the string value into a safety level either from an
+ * integer form like '1' or a label like 'safe'.
+ * 
+ * Returns: safety level enumeration value or <0 on error
+ **/
+int
+flickcurl_get_safety_level_from_string(const char* safety_level_string)
+{
+  char* endptr=NULL;
+  int safety_level= -1;
+
+  safety_level=(int)strtol(safety_level_string, &endptr, 10);
+  /* If not all of string was used - fail */
+  if(endptr && *endptr)
+    safety_level= -1;
+  if(safety_level < 1 || safety_level > SAFETY_LEVEL_COUNT) {
+    int i;
+    for(i=1; i< SAFETY_LEVEL_COUNT; i++)
+      if(!strcmp(flickcurl_safety_level_labels[i], safety_level_string)) {
+        safety_level=i;
+        break;
+      }
+  }
+
+  return safety_level;
+}
