@@ -32,6 +32,75 @@
 #error "Cannot define both OFFLINE and CAPTURE"
 #endif
 
+
+#ifdef FLICKCURL_DEBUG
+
+#ifndef FLICKCURL_ASSERT_DIE
+#define FLICKCURL_ASSERT_DIE abort();
+#endif
+
+#else
+/* No debugging messages */
+#ifndef FLICKCURL_ASSERT_DIE
+#define FLICKCURL_ASSERT_DIE
+#endif
+
+#endif
+
+
+#ifdef FLICKCURL_DISABLE_ASSERT_MESSAGES
+#define FLICKCURL_ASSERT_REPORT(line)
+#else
+#define FLICKCURL_ASSERT_REPORT(msg) fprintf(stderr, "%s:%d: (%s) assertion failed: " msg "\n", __FILE__, __LINE__, __func__);
+#endif
+
+
+#ifdef FLICKCURL_DISABLE_ASSERT
+
+#define FLICKCURL_ASSERT(condition, msg) 
+#define FLICKCURL_ASSERT_RETURN(condition, msg, ret) 
+#define FLICKCURL_ASSERT_OBJECT_POINTER_RETURN(pointer, type) do { \
+  if(!pointer) \
+    return; \
+} while(0)
+#define FLICKCURL_ASSERT_OBJECT_POINTER_RETURN_VALUE(pointer, type, ret)
+
+#else
+
+#define FLICKCURL_ASSERT(condition, msg) do { \
+  if(condition) { \
+    FLICKCURL_ASSERT_REPORT(msg) \
+    FLICKCURL_ASSERT_DIE \
+  } \
+} while(0)
+
+#define FLICKCURL_ASSERT_RETURN(condition, msg, ret) do { \
+  if(condition) { \
+    FLICKCURL_ASSERT_REPORT(msg) \
+    FLICKCURL_ASSERT_DIE \
+    return ret; \
+  } \
+} while(0)
+
+#define FLICKCURL_ASSERT_OBJECT_POINTER_RETURN(pointer, type) do { \
+  if(!pointer) { \
+    FLICKCURL_ASSERT_REPORT("object pointer of type " #type " is NULL.") \
+    FLICKCURL_ASSERT_DIE \
+    return; \
+  } \
+} while(0)
+
+#define FLICKCURL_ASSERT_OBJECT_POINTER_RETURN_VALUE(pointer, type, ret) do { \
+  if(!pointer) { \
+    FLICKCURL_ASSERT_REPORT("object pointer of type " #type " is NULL.") \
+    FLICKCURL_ASSERT_DIE \
+    return ret; \
+  } \
+} while(0)
+
+#endif
+
+
 /* flickcurl.c */
 /* Prepare Flickr API request - GET or POST with URI parameters with auth */
 int flickcurl_prepare(flickcurl *fc, const char* method, const char* parameters[][2], int count);
@@ -54,12 +123,15 @@ flickcurl_blog** flickcurl_build_blogs(flickcurl* fc, xmlXPathContextPtr xpathCt
 /* invoke an error */
 void flickcurl_error(flickcurl* fc, const char *message, ...);
 
-/* Convert a unix timestamp into an ISO string */
+/* Convert a unix timestamp into an ISO dateTime string */
 char* flickcurl_unixtime_to_isotime(time_t unix_time);
 
 /* Convert a unix timestamp into an SQL timestamp string */
 char* flickcurl_unixtime_to_sqltimestamp(time_t unix_time);
 
+/* Convert a SQL timestamp to an ISO dateTime string */
+char* flickcurl_sqltimestamp_to_isotime(const char* timestamp);
+
 /* Evaluate an XPath to get the string value */
 char* flickcurl_xpath_eval(flickcurl *fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr);
 
@@ -123,6 +195,7 @@ flickcurl_size** flickcurl_build_sizes(flickcurl* fc, xmlXPathContextPtr xpathCt
 
 /* tags.c  */
 flickcurl_tag** flickcurl_build_tags(flickcurl* fc, flickcurl_photo* photo, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* tag_count_p);
+flickcurl_tag_clusters* flickcurl_build_tag_clusters(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr);
 
 /* ticket.c */
 flickcurl_ticket** flickcurl_build_tickets(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* ticket_count_p);
@@ -130,6 +203,8 @@ flickcurl_ticket** flickcurl_build_tickets(flickcurl* fc, xmlXPathContextPtr xpa
 /* vsnprintf.c */
 extern char* my_vsnprintf(const char *message, va_list arguments);
 
+/* video.c */
+flickcurl_video* flickcurl_build_video(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr);
 
 struct flickcurl_s {
   int total_bytes;
@@ -216,3 +291,13 @@ struct flickcurl_s {
   FILE* fh;
 #endif
 };
+
+struct flickcurl_serializer_s
+{
+  flickcurl* fc;
+  void *data;
+  flickcurl_serializer_factory* factory;
+};
+
+void flickcurl_serializer_init(void);
+void flickcurl_serializer_terminate(void);
