@@ -83,7 +83,10 @@ static const char* flickcurl_photo_field_label[PHOTO_FIELD_LAST+1]={
   "locality_woeid",
   "county_woeid",
   "region_woeid",
-  "country_woeid"
+  "country_woeid",
+  "usage_candownload",
+  "usage_canblog",
+  "usage_canprint"
 };
 
 
@@ -114,6 +117,9 @@ void
 flickcurl_free_photo(flickcurl_photo *photo)
 {
   int i;
+
+  FLICKCURL_ASSERT_OBJECT_POINTER_RETURN(photo, flickcurl_photo);
+
   for(i=0; i <= PHOTO_FIELD_LAST; i++) {
     if(photo->fields[i].string)
       free(photo->fields[i].string);
@@ -129,9 +135,15 @@ flickcurl_free_photo(flickcurl_photo *photo)
   if(photo->uri)
     free(photo->uri);
   
+  if(photo->media_type)
+    free(photo->media_type);
+  
   if(photo->place)
     flickcurl_free_place(photo->place);
   
+  if(photo->video)
+    flickcurl_free_video(photo->video);
+  
   free(photo);
 }
 
@@ -203,6 +215,12 @@ static struct {
     VALUE_TYPE_PHOTO_URI
   }
   ,
+  {
+    (const xmlChar*)"./@media",
+    PHOTO_FIELD_none,
+    VALUE_TYPE_MEDIA_TYPE
+  }
+  ,
   {
     (const xmlChar*)"./@dateuploaded",
     PHOTO_FIELD_dateuploaded,
@@ -529,6 +547,24 @@ static struct {
     VALUE_TYPE_STRING
   }
   ,
+  {
+    (const xmlChar*)"./usage/@candownload",
+    PHOTO_FIELD_usage_candownload,
+    VALUE_TYPE_BOOLEAN
+  }
+  ,
+  {
+    (const xmlChar*)"./usage/@canblog",
+    PHOTO_FIELD_usage_canblog,
+    VALUE_TYPE_BOOLEAN
+  }
+  ,
+  {
+    (const xmlChar*)"./usage/@canprint",
+    PHOTO_FIELD_usage_canprint,
+    VALUE_TYPE_BOOLEAN
+  }
+  ,
   { 
     NULL,
     (flickcurl_photo_field_type)0,
@@ -617,6 +653,12 @@ flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx,
           datatype=VALUE_TYPE_NONE;
           break;
 
+        case VALUE_TYPE_MEDIA_TYPE:
+          photo->media_type=string_value;
+          string_value=NULL;
+          datatype=VALUE_TYPE_NONE;
+          break;
+
         case VALUE_TYPE_UNIXTIME:
         case VALUE_TYPE_DATETIME:
 
@@ -676,6 +718,14 @@ flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx,
     photo->place=flickcurl_build_place(fc, xpathNodeCtx,
                                        (const xmlChar*)"./location");
 
+    photo->video=flickcurl_build_video(fc, xpathNodeCtx,
+                                       (const xmlChar*)"./video");
+    
+    if(!photo->media_type) {
+      photo->media_type=(char*)malloc(6);
+      strncpy(photo->media_type, "photo", 6);
+    }
+
     if(xpathNodeCtx)
       xmlXPathFreeContext(xpathNodeCtx);
 
@@ -723,6 +773,8 @@ flickcurl_free_photos(flickcurl_photo** photos)
 {
   int i;
   
+  FLICKCURL_ASSERT_OBJECT_POINTER_RETURN(photos, flickcurl_photo_array);
+
   for(i=0; photos[i]; i++)
     flickcurl_free_photo(photos[i]);
   free(photos);
