@@ -193,6 +193,9 @@ flickcurl_photos_getAllContexts(flickcurl* fc, const char* photo_id)
  * 
  * Fetch a list of recent photos from the calling users' contacts.
  *
+ * Optional extra type 'media' that will return an extra media=VALUE
+ * for VALUE "photo" or "video".  API addition 2008-04-07.
+ *
  * Implements flickr.photos.getContactsPhotos (0.11)
  * 
  * Return value: non-0 on failure
@@ -280,6 +283,9 @@ flickcurl_photos_getContactsPhotos(flickcurl* fc,
  * 
  * Fetch a list of recent public photos from a users' contacts.
  *
+ * Optional extra type 'media' that will return an extra media=VALUE
+ * for VALUE "photo" or "video".  API addition 2008-04-07.
+ *
  * Implements flickr.photos.getContactsPublicPhotos (0.12)
  * 
  * Return value: a list of photos or NULL on failure
@@ -940,6 +946,9 @@ flickcurl_photos_getPerms(flickcurl* fc, const char* photo_id)
  * 
  * Returns a list of the latest public photos uploaded to flickr.
  *
+ * Optional extra type 'media' that will return an extra media=VALUE
+ * for VALUE "photo" or "video".  API addition 2008-04-07.
+ *
  * Implements flickr.photos.getRecent (0.12)
  * 
  * Return value: non-0 on failure
@@ -1187,6 +1196,9 @@ flickcurl_photos_getWithoutGeoData(flickcurl* fc,
  * description, tags) may have been changed or a comment has been
  * added (or just modified somehow :-)
  *
+ * Optional extra type 'media' that will return an extra media=VALUE
+ * for VALUE "photo" or "video".  API addition 2008-04-07.
+ *
  * Implements flickr.photos.recentlyUpdated (0.12)
  * 
  * Return value: non-0 on failure
@@ -1316,13 +1328,33 @@ flickcurl_photos_removeTag(flickcurl* fc, const char* tag_id)
  *
  * Flickcurl 1.0: Added place_id for places API as announced 2008-01-11
  * http://tech.groups.yahoo.com/group/yws-flickr/message/3688
+ *
+ * Optional parameter "media" that defaults to "all" but can also be
+ * set to "photos" or "videos" to filter results by media type.
+ * API addition 2008-04-07.
+ *
+ * Optional parameter "has_geo" for any photo that has been geotagged.
+ * As announced 2008-06-27
+ * http://tech.groups.yahoo.com/group/yws-flickr/message/4146
+ *
+ * Optional parameters "lat", "lon", "radius" and "radius_units" added
+ * for doing radial geo queries from point (lat, lon) within
+ * radius/radius_units.  radius_units default is "km".
+ * As announced 2008-06-27
+ * http://tech.groups.yahoo.com/group/yws-flickr/message/4146
+ *
+ * (Experimental) Optional parameter "contacts" requires requires
+ * that the "user_id" field also is set.  Valid values are "all" or
+ * "ff" for just friends and family.
+ * As announced 2008-06-30
+ * http://tech.groups.yahoo.com/group/yws-flickr/message/4162
  * 
  * Return value: an array of #flickcurl_photo or NULL
  **/
 flickcurl_photo**
 flickcurl_photos_search(flickcurl* fc, flickcurl_search_params* params)
 {
-  const char* parameters[29][2];
+  const char* parameters[36][2];
   int count=0;
   xmlDocPtr doc=NULL;
   xmlXPathContextPtr xpathCtx=NULL; 
@@ -1334,6 +1366,9 @@ flickcurl_photos_search(flickcurl* fc, flickcurl_search_params* params)
   char content_type_s[2];
   char per_page_s[4];
   char page_s[4];
+  char lat_s[32];
+  char lon_s[32];
+  char radius_s[32];
   
   if(params->user_id) {
     parameters[count][0]  = "user_id";
@@ -1440,6 +1475,41 @@ flickcurl_photos_search(flickcurl* fc, flickcurl_search_params* params)
     parameters[count][0]  = "place_id";
     parameters[count++][1]= params->place_id;
   }
+  if(params->media) {
+    parameters[count][0]  = "media";
+    parameters[count++][1]= params->media;
+  }
+  if(params->has_geo) {
+    parameters[count][0]  = "has_geo";
+    parameters[count++][1]= "1";
+  }
+  if(params->radius) {
+    if(params->lat) {
+      sprintf(lat_s, "%f", params->lat);
+      parameters[count][0]  = "lat";
+      parameters[count++][1]= lat_s;
+    }
+    if(params->lon) {
+      sprintf(lon_s, "%f", params->lon);
+      parameters[count][0]  = "lon";
+      parameters[count++][1]= lon_s;
+    }
+
+    if(params->radius) {
+      sprintf(radius_s, "%f", params->radius);
+      parameters[count][0]  = "radius";
+      parameters[count++][1]= radius_s;
+    
+      if(params->radius_units) {
+        parameters[count][0]  = "radius_units";
+        parameters[count++][1]= params->radius_units;
+      }
+    }
+  }
+  if(params->contacts && params->user_id) {
+    parameters[count][0]  = "contacts";
+    parameters[count++][1]= params->contacts;
+  }
   parameters[count][0]  = NULL;
 
   if(flickcurl_prepare(fc, "flickr.photos.search", parameters, count))
